@@ -28,7 +28,7 @@ class QmlPlugins : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
     public:
-        virtual void registerTypes(const char * uri);
+        void registerTypes(const char * uri) Q_DECL_OVERRIDE;
 };
 
 #endif // PRINT_MANAGER_PLUGINS_H
